Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(206)

Unified Diff: chrome/browser/chromeos/proxy_config_service_impl.h

Issue 2445153002: Move onc and proxy pref names to components. (Closed)
Patch Set: ONC_EXPORT Created 4 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/chromeos/proxy_config_service_impl.h
diff --git a/chrome/browser/chromeos/proxy_config_service_impl.h b/chrome/browser/chromeos/proxy_config_service_impl.h
index 2b43064ffcf13cc392cdb0e273a8d181539d03c4..75a6dce2e02562b7058e088afe90badeedcec419 100644
--- a/chrome/browser/chromeos/proxy_config_service_impl.h
+++ b/chrome/browser/chromeos/proxy_config_service_impl.h
@@ -63,10 +63,11 @@ class ProxyConfigServiceImpl : public PrefProxyConfigTrackerImpl,
// Returns Pref Proxy configuration if available or a proxy config dictionary
// applied to the default network.
// Returns NULL if no Pref Proxy configuration and no active network.
// |profile_prefs| must be not NULL.
static std::unique_ptr<ProxyConfigDictionary> GetActiveProxyConfigDictionary(
- const PrefService* profile_prefs);
+ const PrefService* profile_prefs,
+ const PrefService* local_state_prefs);
private:
// Called when any proxy preference changes.
@@ -63,10 +63,11 @@ class ProxyConfigServiceImpl : public PrefProxyConfigTrackerImpl,
// Returns Pref Proxy configuration if available or a proxy config dictionary
// applied to the default network.
- // Returns NULL if no Pref Proxy configuration and no active network.
- // |profile_prefs| must be not NULL.
+ // Returns null if no Pref Proxy configuration and no active network.
+ // |profile_prefs| and |local_state_prefs| must be not null.
static std::unique_ptr<ProxyConfigDictionary> GetActiveProxyConfigDictionary(

Powered by Google App Engine
This is Rietveld 408576698